@@ -118,11 +118,7 @@ deriveEqClass eClass name = do
   case info of
     DatatypeInfo { datatypeContext   = ctxt
                  , datatypeName      = parentName
-#if MIN_VERSION_th_abstraction(0,3,0)
                  , datatypeInstTypes = instTypes
-#else
-                 , datatypeVars      = instTypes
-#endif
                  , datatypeVariant   = variant
                  , datatypeCons      = cons
                  } -> do
@@ -152,11 +148,7 @@ makeEqClass eClass name = do
   case info of
     DatatypeInfo { datatypeContext   = ctxt
                  , datatypeName      = parentName
-#if MIN_VERSION_th_abstraction(0,3,0)
                  , datatypeInstTypes = instTypes
-#else
-                 , datatypeVars      = instTypes
-#endif
                  , datatypeVariant   = variant
                  , datatypeCons      = cons
                  } -> do
