@@ -219,11 +219,7 @@ deriveFunctorClass fc opts name = do
   case info of
     DatatypeInfo { datatypeContext   = ctxt
                  , datatypeName      = parentName
-#if MIN_VERSION_th_abstraction(0,3,0)
                  , datatypeInstTypes = instTypes
-#else
-                 , datatypeVars      = instTypes
-#endif
                  , datatypeVariant   = variant
                  , datatypeCons      = cons
                  } -> do
@@ -259,11 +255,7 @@ makeFunctorFun ff opts name = do
   case info of
     DatatypeInfo { datatypeContext   = ctxt
                  , datatypeName      = parentName
-#if MIN_VERSION_th_abstraction(0,3,0)
                  , datatypeInstTypes = instTypes
-#else
-                 , datatypeVars      = instTypes
-#endif
                  , datatypeVariant   = variant
                  , datatypeCons      = cons
                  } -> do
